@@ -722,6 +722,19 @@ class CloneMixinTestCase(TestCase):
         self.assertEqual(edition.book.name, edition_clone.book.name)
         _clone_m2o_or_o2m_fields_mock.assert_called()
 
+    @patch(
+        "sample.models.Edition._clone_m2o_or_o2m_fields",
+        new_callable=PropertyMock,
+    )
+    def test_cloning_nullable_many_to_one(self, _clone_m2o_or_o2m_fields_mock):
+        _clone_m2o_or_o2m_fields_mock.return_value = ["book"]
+
+        edition = Edition.objects.create(seq=1, book=None)
+        edition.make_clone()
+
+        self.assertIsNone(edition.book)
+        _clone_m2o_or_o2m_fields_mock.assert_called()
+
     def test_cloning_complex_model_relationships(self):
         house = House.objects.create(name="My House")
 
